diff --git a/gemeinsamforschen/src/main/webapp/assets/js/unstructuredAnnotation.js b/gemeinsamforschen/src/main/webapp/assets/js/unstructuredAnnotation.js
index ecac045a0d2130b9ba11e58d986796e255151aad..8c770dfd5940506ec1c391b74ef9e063aac16869 100644
--- a/gemeinsamforschen/src/main/webapp/assets/js/unstructuredAnnotation.js
+++ b/gemeinsamforschen/src/main/webapp/assets/js/unstructuredAnnotation.js
@@ -12,12 +12,12 @@ $(document).ready(function() {
         getAllSubmissionParts(getSubmissionIdFromUrl(), function (response) {
 
             // iterate over response
-            for (var i = 0; i < response.length; i++) {
+            for (let i = 0; i < response.length; i++) {
                 // save current category and body
                 let category = response[i].category;
                 let body = response[i].body;
                 // iterate over body and handle every selection
-                for (var j = 0; j < body.length; j++) {
+                for (let j = 0; j < body.length; j++) {
                     handleCategorySelection(category.toLowerCase(), body[j].startCharacter, body[j].endCharacter);
                 }
             }
diff --git a/gemeinsamforschen/src/main/webapp/assets/js/unstructuredRest.js b/gemeinsamforschen/src/main/webapp/assets/js/unstructuredRest.js
index 819c8221973a4af31e0afcc1be8cc1a87f1cfe3b..047018efac765464de02fd05353cf2ab1396f6b1 100644
--- a/gemeinsamforschen/src/main/webapp/assets/js/unstructuredRest.js
+++ b/gemeinsamforschen/src/main/webapp/assets/js/unstructuredRest.js
@@ -68,14 +68,15 @@ function createSubmissionPart(submissionPartPostRequest, responseHandler) {
 }
 
 /**
  * GET: Get a specific submission part for a given id
  *
  * @param id The id of the submission part
  * @param responseHandler The response handler
  * @param errorHandler The error handler
  */
-function getSubmissionPart(id, responseHandler, errorHandler) {
-    var url = "../rest/submissions/part/" + id;
+function getSubmissionPart(id, category, responseHandler, errorHandler) {
+    var url = "/full/" + id + "/category/" + category;
     $.ajax({
         url: url,
         type: "GET",
@@ -68,14 +68,15 @@ function createSubmissionPart(submissionPartPostRequest, responseHandler) {
 
 /**
- * GET: Get a specific submission part for a given id
+ * GET: Get a specific submission part for a given full submission id and its category
  *
@@ -68,14 +68,15 @@ function createSubmissionPart(submissionPartPostRequest, responseHandler) {
  *
- * @param id The id of the submission part
+ * @param id The id of the full submission
+ * @param category The category of the submission part
  * @param responseHandler The response handler
  * @param errorHandler The error handler